@@ -2,10 +2,8 @@
 from typing import Any
 from typing import Optional
 
-from typing_extensions import Protocol
 
-
-class OnProgress(Protocol):
+class OnProgress():
     def __call__(
         self, stream: Any, chunk: bytes, bytes_remaining: int
     ) -> None:
@@ -24,7 +22,7 @@ class OnProgress(Protocol):
         ...
 
 
-class OnComplete(Protocol):
+class OnComplete():
     def __call__(self, stream: Any, file_path: Optional[str]) -> None:
         """On download complete handler function.
 
